#
# spec file for package python-pymol
#
# Copyright (c) 2021 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%{?!python_module:%define python_module() python-%{**} python3-%{**}}
%define skip_python2 1
%define oldpython python
%define modname pymol-open-source
Name:           python-pymol
Version:        2.5.0
Release:        1.2
Summary:        A Molecular Viewer
License:        Python-2.0
Group:          Productivity/Scientific/Chemistry
URL:            https://pymol.org/2/
Source0:        https://github.com/schrodinger/%{modname}/archive/v%{version}/%{modname}-%{version}.tar.gz
# PATCH-FIX-OPENSUSE no-build-date.patch dhall@wustl.edu -- patch eliminates build date
Patch0:         no-build-date.patch
# PATCH-FIX-OPENSUSE no-o3.patch tchvatal@suse.com -- do not add O3 to the code
Patch1:         no-o3.patch
BuildRequires:  %{python_module devel}
BuildRequires:  %{python_module numpy-devel}
BuildRequires:  %{python_module pytest}
BuildRequires:  %{python_module qt5-devel}
BuildRequires:  %{python_module setuptools}
BuildRequires:  fdupes
BuildRequires:  freetype2-devel
BuildRequires:  gcc-c++
BuildRequires:  glew-devel
BuildRequires:  glm-devel
BuildRequires:  msgpack-cxx-devel
BuildRequires:  libpng-devel
BuildRequires:  libxml2-devel
BuildRequires:  mmtf-cpp-devel
BuildRequires:  netcdf-devel
BuildRequires:  python-rpm-macros
Requires:       python-numpy
Requires:       python-qt5
Requires:       python-pmw
Requires(post): update-alternatives
Requires(postun):update-alternatives
Obsoletes:      pymol < %{version}
Provides:       pymol = %{version}
%python_subpackages

%description
PyMOL is a molecular graphics system targetted at medium to large
biomolecules like proteins. It can generate molecular graphics
images and animations.

Features include:

* Visualization of molecules, molecular trajectories and surfaces
  of crystallography data or orbitals
* Molecular builder and sculptor
* Internal raytracer and movie generator
* Fully extensible and scriptable via a python interface

The file formats PyMOL can read include PDB, XYZ, CIF, MDL Molfile,
ChemDraw, CCP4 maps, XPLOR maps and Gaussian cube maps.

%prep
%setup -q -n %{modname}-%{version}
%autopatch -p1
%build
export CXXFLAGS="%{optflags} -fno-strict-aliasing"
%python_build

%install
%python_install
%python_clone -a %{buildroot}%{_bindir}/pymol
%python_expand %fdupes %{buildroot}%{$python_sitearch}

%post
%python_install_alternative pymol

%postun
%python_uninstall_alternative pymol

%check

%files %{python_files}
%doc README ChangeLog
%license LICENSE
%python_alternative %{_bindir}/pymol
%{python_sitearch}*

%changelog
* Fri Aug 11 2023 <hsk17@mail.de>
- update to 2.5.0
  * File Import/Export
  - DX binary map import (*dxbin)
  - PDB/MMTF export: symmetry information now added
  - Improved FASTA import
  - Support for map.gz and mrc.gz extensions
  * Builder & Panels
  - Improved Fuse command (disallows hypervalent bonds,
    substitute monovalent atoms instead of attaching to them)
  - Customizable keyboard shortcut menu
  - Properties inspector now supports unsetting settings with
    “Delete” key
  * Graphics & Visualization
  - Ray interior colors now match primitives with
    `set ray_interior_color, atomic`
  - Isomesh transparency support
  - `sphere_mode` 5 removed (9 as replacement)
  - Curved cartoon cylindrical helices
  - Isosurface generation via marching cubes with setting
    `isosurface_algorithm, (0, 1)` (0 requires VTKm)
  * PBC Handling
  - Periodic boundary conditions supported in rebond, smooth,
    and intra_fit
  * Python API
  - Python 2 support removed
  - pbc argument added to rebond, smooth, and intra_fit
  - png(None) returns bytes
  - scene_order() allows list for `names`
  - pbc_wrap() and pbc_unwrap added
  - matrix_reset() supports `state=0` for all states
  - editing_ring() added
  - unset now restores the default value for global settings
  - load_traj now uses state=1 by default
  - get_area command and dots representation: Exclude
    “flag ignore” atoms
- no-o3.patch: adapt to 2.5.0
- spec file:
  * some tweaks to adapt to 2.5.0
  * remove test related stuff; test run commands are removed
    from 2.5.0 as unmaintained and useless
* Wed May 19 2021 Steve Kowalik <steven.kowalik@suse.com>
- Remove the execute bit from some test scripts to remove a spurious
  requirement.
* Sun Feb 21 2021 andy great <andythe_great@pm.me>
- Skip python3.6 because numpy no longer support it.
- Add mmtf-cpp-devel and use msgpackc.
- Attempt to get the test to run.
  * Use _service to download pymol-testing for test data.
  * Use bcond to enable/disable testing arguments.
  * Pymol seems to need itself to test.
  * Add %%check section.
* Tue Sep  1 2020 Matej Cepl <mcepl@suse.com>
- Update to 2.4.0:
  * load_traj
  - support netcdf format
  - support `selection` argument with all file formats
  * CCP4/MRC Map Support
  - Distinguish .ccp4 and .mrc extensions (regarding origin)
  - .map extension: auto-detect the format
  * New distance mode 8
  * MMTF export: Consider `pdb_retain_ids` setting
  * GLTF export (based on collada2gltf)
  * New `internal_gui_name_color_mode` setting
  * MPEG4 Movie export: Apply `movie_fps` setting to exported
    file
  * Python API
  - Improved error handling with exceptions
  - New: cmd.rebond()
  - New: cmd.get_capabilities()
  - Fix: cmd.get_bonds() state off by one
  - cmd.fit() et al.: raise on error
  * Launch Options
  - Restore `-V` launch argument for external GUI height
  - macOS: `open` event opens new window
* Sat Feb  1 2020 Stefan Brüns <stefan.bruens@rwth-aachen.de>
- Remove glew runtime dependency (only contains debug tools and
  documentation).
- Remove freeglut build dependency (unused unless enabled with
  '--glut' setup.py option).
- Use https for URL.
* Mon Feb 11 2019 Matej Cepl <mcepl@suse.com>
- Upgrade to 2.3.0:
  * atom-level cartoon_transparency
  * aln export for Nucleic Acids
  * new API function: cmd.set_raw_alignment()
  * fetch async=0 by default
  * fast MMTF export (requires mmtf-cpp)
  * new setting: seq_view_gap_mode
* Thu Jan  3 2019 opensuse-packaging@opensuse.org
- Update to version 2.2.0+git.1544795767.c481a7c1:
  * fix SettingUniqueFromPyList w/ float3
  * remove pymol::Image::Image(T&& vec, ...)
  * refactor: pymol::Image tweaks
  * rewrite "get_raw_alignment"
  * refactor: pymol::vla::operator->() usage
  * fix #16 pymol::vla::operator[] for VS2015 32bit
  * fix pymol::vla::operator+ for VS2015
  * pymol::Image::pixels()
  * fix build
  * fix macOS build
- Switch off msgpackc as we don't have mmtf-cpp packaged.
* Thu Aug 23 2018 tchvatal@suse.com
- Version update to 2.2.0:
  * Switch devel links to github
  * No finegraned news file see ChangeLog for commit info
- Rebase patch no-o3.patch
* Thu Aug 23 2018 tchvatal@suse.com
- Fix fdupes call
- Install license and docu files
* Wed Jun  6 2018 jengelh@inai.de
- Trim marketing words from description.
* Wed May  2 2018 tchvatal@suse.com
- Update to normal release that was released on 2018-03-19, 2 commits
  changing tiny stuff compared to svn rev 4187
- Rename pymol to python-pymol to respect the packaging guidelines
- Fix qt5 devel python dependency to pull py3 and py2 both
- Obey system optflags instead of passing -O3
  * no-o3.patch
* Tue Mar 13 2018 dhall@wustl.edu
- update to svn rev 4187
  * PyQt interface (2.1.0)
  * stick_round_nub for COLLADA export
  * UTF-8 in feedback
  * display_scale_factor (ported from Incentive PyMOL)
  * dx map import: support "type float" and skewed delta
  * new selection keywords: polymer.protein polymer.nucleic
  * new command: multifilesave
  * MMTF export (requires simplemmtf python module)
  * select: present, state -1 -> current object state
  * create: source_state = -1 -> current
    (was: source_state = -1/0 -> all)
  * cif: support quoted '?' and '.' as values
    cif_get_array -> None instead of empty string for ? and .
  * fix copy discrete object w/o coords
  * fix loading pdbqr AutoDock 4 atom types
  * fix get_model('none') and get_str('mol', 'none')
  * h_add refactored: 5x faster, support discrete objects-
* Tue Jan 16 2018 dhall@wustl.edu
- update to svn rev 4184
  * Python 3.7 support (https://sf.net/p/pymol/bugs/197/)
  * enable align with alt-codes
  - allow matching of non-alt-code to alt-code atoms in alignments
  - swap sorting priority of 'name' and 'alt' identifiers
  - sort empty 'alt' before non-empty 'alt'
  * flags 6 and 7 for protein and nucleic acid
  * mmCIF: read _atom_site.pdbx_formal_charge
  * improve coordinate loading from mmcif chem_comp files
  - ignore columns with all ? (missing) values
  - select columns with "chem_comp_cartn_use" setting
  * fix h_add: skip missing coordinates
  * Python API: New "auto library mode". Automatically start a
    non-GUI PyMOL instance if the pymol.cmd API is used without
    running pymol.launch() first
  * pdb_echo_tags for mmCIF and MMTF
  * command parser: improve exception handling
  * fix some PSE export memory leaks
  * pymol2.cmd2: eliminate (non-weak) circular references
  * movie making: reinterpolate after add_nutate/add_roll etc.
  * support "module:callable" in loadfunctions/safefunctions
  * yellow state indicator for discrete objects
  * mpng modal draw improvements
  * fix elements from .gro files (pymol/bugs/196, r4181 regression)
  * save .mtl: raise exception
  * Python 3:
  - fix "GUI Font Size" dialog (pmw/bugs/47)
  - fix COLLADA export
  * some elements wrong from SDF and XYZ
  * pse_export_version support with Python 3
* Fri Oct 20 2017 dhall@wustl.edu
- 1.9.0.0
  * L > residues (oneletter)
  * fix py3 crash in "A > copy to object"
  * fix scene object visibility with hidden groups
  * fix "ending" after loading movie session
* Wed Sep 20 2017 dhall@wustl.edu
- update to svn rev 4177
  * expose "oneletter" to label/iterate
  * sequence viewer: MSE=M SEC=U
  * wire/licorice rep aliases
  * menu: A > copy to object
  * new commands: copy_to, uniquify
  * fix slow 'extract' performance
* Wed Aug 16 2017 dhall@wustl.edu
- obsolete and provide pymol
* Fri Aug  4 2017 dhall@wustl.edu
- move to python singlespec
* Fri Aug  4 2017 dhall@wustl.edu
- 1.8.7.0
  * support "not ..." and "enabled" in name patterns (e.g.: delete not enabled)
  * improve/fix unicode+utf-8 handling for labels
  * iterate color settings: type int (e.g.: iterate all, print(s.sphere_color))
  * fix cmd.load with contents https://sf.net/p/pymol/mailman/message/35966326/
  * fix ray tracing of stick_ball + valence https://sf.net/p/pymol/mailman/message/35928857/
  * web.pymolhttpd -> pymol.pymolhttpd
    Generic "web" name conflicts with webpy
    https://sf.net/p/pymol/bugs/148/
  * make build reproducible
    https://sf.net/p/pymol/patches/12/
  * delete obsolete packaging files
  * internal command line: consistent behavior across platforms
  * new "label" selection operator
  * alter_state: remove restriction on x/y/z/flags
  * iterate/label: expose "state" for discrete atoms
  * CTRL+L drag/click -> move/center in 3-Button-Viewing mode
  * auto-detect $PREFIX/share/pymol as $PYMOL_PATH
  * locale LC_NUMERIC=C float parsing/formatting
  * Python 3: fix wrong PyCapsule_New destructor
  * PSE compatibility between Python 2 and 3
* Fri May  5 2017 dhall@wustl.edu
- 1.8.6.1 fixes
  * Python 3.6 fixes
  * Python 3: fix builder bond order buttons (Red Hat Bug 1442127)
  * fix MAE export PDB residue/atom names
  * restored "scene_animation" setting (1.7.6 regression)
  * restored "import cmd" prevention (1.8.6.0 regression)
* Mon Mar 13 2017 dhall@wustl.edu
- remove explicity library dependency
* Mon Mar 13 2017 dhall@wustl.edu
- require libmsgpack
* Mon Mar 13 2017 dhall@wustl.edu
- 1.8.6.0 release
  * mmtf: "ignore" flag for hetatm
  * mmtf: msgpack version check
  * INSTALL: env variables documentation
  * Tcl/Tk menu updates
  * fast MMTF load support in C++ (adds msgpack-c dependency)
  * extra_fit: report RMS for method=cealign; Thanks to Hongbo Zhu
  * CTRL-L ligand zoom
  * preset > classified (auto_show_classified equivalent)
  * preset > interface (ported from Incentive PyMOL 1.8.0)
  * set_key auto-completion
  * command completion for selection language
  * fix connect_mode=4 for N-H1 and N-H3
  * fix CGO ALPHA and dup COLOR issue
  * width/height arguments for movie export (mpng, movie.produce)
  * fetch: support "fetch EMD-3489"
  * auto_show_classified -1 => 3 for 500k+ atoms
  * pick_shading => surface_color_smoothing off
  * cleanup: eliminate pymol.pymol_launch variable
  * update molfile plugins to VMD version 1.9.3
  * fetch 2fofc/fofc: update URLs, EDS will retire in 2017
  * fix sf#102 pseudoatom multi-state problem
  * editor.attach_amino_acid: fix PRO/N geometry
  * avoid selection keyword name conflicts, append underscore
  * load: allow format=plugin (by extension) and format=plugin:PLUGIN (with PLUGIN being a molfile plugin identifier)
  * load format "vdb": VIPERdb PDB variant with retain_order=1
  * load/load_traj: guess trajectory object
  * fetch
  * new setting "fetch_type_default"
  * type=mmtf: fetch MMTF format
  * type=2fofc/fofc: get spacegroup from PDBe API
  * update download URLs
  * new setting: editor_auto_measure
  * new default: ray_transparency_oblique_power=4.0
  * "update" command: support "current state" (-1)
  * alter elem -> update protons and vdw
  * don't allow "import cmd" (corrupts PyMOL namespace)
  * support "python -m pymol" to launch PyMOL
* Thu Dec  1 2016 dhall@wustl.edu
- 1.8.4.0 release
* Thu Sep 29 2016 dhall@wustl.edu
- update to svn rev 4161
  * pse_export_version: legacy scenes support
  * use ignore_case setting with set_name command
  * setup.py: detect anaconda prefix
* Thu Sep 22 2016 dhall@wustl.edu
- update to svn rev 4160
  * experimental MMTF load support
  * map export in CCP4 format
  * SDF V3000 import/export support
  * refactor molecular file formats export: Unified handling of PDB, PQR, mmCIF, MOL2, SDF, XYZ, MAE
  * PLY geometry import (as CGO)
  * new command: unset_deep
  * new setting: cartoon_all_alt: Create cartoon for every alt code
  * stick_h_scale: default=1.0 (was: 0.4) but remove dependency on negative stick_radius
  * auto_show_classified: Visualize small (< 50 atoms) polymer classified molecules like organic
  * bymol selection operator: ignore zero-order bonds
  * menu: isomesh/surface negative color
  * improve alignment of residues with unknown resn (e.g. ligands):
    give a match score of 5 to perfect matches of unknown residue codes.
    Previously, those got match score -1.
  * remove broken and obsolete "PMO" file support
  * use "label_digits" setting with "label" command
  * do not resize window when loading a session file
  * fix ignored SCALE w/ identity rotation (e.g. 1WAP)
  * fix "scene auto, clear" (Scene > Delete)
  * new setting: pick_shading: do flat shading for programmable image color analysis
  * experimental cmd.raw_image_callback: post cmd.draw() callback
* Mon Jun 20 2016 dhall@wustl.edu
- update to svn rev 4159
  * fix crash with ray tracing very large images
  - use size_t instead of int for ray trace image buffer size
  - correct image buffer size for antialias (was oversampled twice)
  * fix crash with "align" and atoms without coordinates
  * fix mutagenesis wizard "No Mutation" (update and rms commands)
  * experimental FreeBSD support
  * fix/silence various compiler warnings
  * partly fixes sf#177, sf#178
  * fix crash when loading PSE with bg_image_filenamefix ray trace memory limit; fix align crash
* Tue Apr 19 2016 dhall@wustl.edu
- update to svnrev 4155
  * experimental setting "pse_binary_dump"
  * get_sasa_relative (command ported from Incentive PyMOL)
  * Color menu uses util.color_deep (ported from Incentive PyMOL)
  * C > by rep (ported from Incentive PyMOL)
  * fix crash when saving mesh PSE without map
  * fix isosurface invalidation when setting surface_negative_visible
  * new setting: collada_background_box (by Jared Sampson)
  * improve unicode filename loading
  * fix "unset" of non-numeric settings
* Mon Mar 21 2016 dhall@wustl.edu
- update to svnrev 4153/1.8.1.2
  * new setting: auto_show_classified
  * cartoon/ribbon: auto-detect CA-only models
  * fix selection macros with wildcards and colon (:) residue ranges (1.8.0 regression)
  * mmCIF: load missing residues independent of cif_use_auth setting
  * fix pdb_insure_orthogonal for multi-model PDBs
* Mon Feb  8 2016 dhall@wustl.edu
- update to svnrev 4149
  * restore ignore_case=on default
  * new setting: ignore_case_chain (default off)
  * new setting: cartoon_gap_cutoff
  * increase PYMOL_MAX_THREADS
  * amber topology loading: bond order 1 for all bonds
  * improve MOL2 file handling
  * new grid_mode=3: grid per object-state
  * distance mode=4: distance between centroids
  * byring: new selection operator
  * "Distances to Rings" mode in measurement wizard
  * basic atom typing for MOL2 export
  * cartoon dash: new dashed loop-like cartoon type
  * object-level settings for measurements
  * iterate: use Python exceptions
  * iterate_state: ignore atomic=0 (fixes crash)
  * format 'xyzstr': enable .gz and URL loading
  * fix crash with object sele length >= 1024
  * re-add -Wno-write-strings
  * fix pmg_tk.skins.normal.encode()
  * fix askopenfilename CANCEL case with multiple=0
  * support segi, resn and name of arbitrary string length
  * expose settings to iterate/alter via "s.<name>"
  * Python 3 compatibility for champ module
  * apbs_tools: apply fixes from Pymol-script-repo
  * Tested with Python 2.6, 2.7, 3.4
  * fix crash with empty alignment object from PSE
  * fix cartoon ray tracing crash
  * fix xyz export and emd fetch
  * backport to pre-c++11 for OS X <= 10.8
  * Tcl/Tk Settings GUI: feedback, radio buttons
  * default alignment_as_cylinders changed to off
  * fix restore legacy scenes with spaces
  * fix invalid write in ObjectGadgetRampUpdate
* Thu Nov  5 2015 dhall@wustl.edu
- update to svnrev 4139
  * color autocomplete for ramps, improve volume blending
  * new default: scene_buttons=on
  * normalize_ccp4_maps=2 -> use mean and stdev from file header
  * fix alignment with atoms w/o coords in a state
  * new filetypes: pdbml, pdbqt, cml
  * cell/symmetry: accept alpha=beta=gamma=0.0 as 90.0
  * leave unknown protons as -1 instead of 0 (lonepair), fixes vdw assingment for unknown elements (1.8 instead of 0.5)
  * reimplement reading full sequence from mmCIF. Only with cif_use_auth=off and retain_order=off. Fill in missing CA atoms for polypeptides.
  * new API function cmd.get_object_ttt()
  * APBS Plugin: --whitespace argument for pdb2pqr
  * fix scene next/previous, was broken on Windows 10
  * fix split_states with non-unique titles
  * fix "File > Run" fails if path has spaces
* Wed Sep 30 2015 dhall@wustl.edu
- update to svnrev 4136
  * cartoon_trace_atoms for sheets, fast connect_mode=4
  * fix crash after headless ray tracing empty cartoon
  * fix building on CentOS 6.3 / python2.6 / gcc 4.4.7
  * cif_keepinmemory, pymol.querying.cif_get_array (experimental)
  * ramp_update (new command)
  * ramp objects now have "A > Range > ..." and "C > ..." menus
  * mmCIF _chem_comp_atom: skip atoms with missing coordinates, prefer ideal over model coordinates
  * cmd.set_key() decorator support
  * fix isosurface all_states rendering
  * pdb_hetatm_guess_valences for CIF loading
  * mutagenesis wizard: improve "apply" performance
  * fix measurement and alignment object partial PSE loading
  * some load/save refactoring
  * keep atom IDs when creating object from selection
  * when renaming group "A" to "B", then also rename entry "A.X" to "B.X"
* Tue Jul 14 2015 dhall@wustl.edu
- update to svnrev 4131
  * fix handling of _pdbx_struct_assembly_gen with repeated asym_id
  * create assembly for multi-state objects
  * no pdb_insure_orthogonal for assemblies
  * fix "File > Run"
  * some "const correctness" refactoring
  * experimental pymol.querying.get_object_ttt
  * fix assemblies for cases like 4f3r which have multiple entries in the
    _pdbx_struct_assembly_gen table
  * fix ref counts in iterate/alter subscripts
  * improve side_chain_helper and nucleic_adic_mode situation
  * eliminate all "try/catch" blocks for std::map lookups
  * clean up some MemoryDebug stuff and remove unused jenarix wrapper
  * some mmCIF bonding fixes
  * Experimental: cmd.get_assembly_ids
  * mmCIF: support "_atom_site.pdbe_label_seq_id"
  * mmCIF: set "ignore" flag for HETATMSs (no surface)
  * improve memory usage and performance of components.cif parsing
  * fix https://sf.net/p/pymol/bugs/169/
  * fetch 'cif' by default
  * fix 5-letter cif-fetch
  * fix mutagenesis wizard for ignore_case=0
  * add some documentation
  * port selection macro parsing to C
  * side-effects for settings min/max
  * warn if selecting with lower-case arguments
  * fix "File > Open" from drive root on Windows
  * std::array replacement for pre-C++11
  * define NOMINMAX, fmax -> std::max
  * correct setting-level handling in presets
  * unset: restore default for string/float3/color, warn for int/bool/float
  * fix "Display > Sequence" needs redisplay
  * migrate seq_view_label_color=white from old PSE
  * remove machine generated code from web/pymolhttpd.py
  * fix segfault in read_pdbx_struct_assembly
  * use snprintf instead of to_string (for c++0x)
  * https://sourceforge.net/p/pymol/patches/10/
  * change default (!) of "ignore_case" setting to off. Case insensitve
    identifier matching is not pctical anymore with large structures
    which use upper and lower case chain identifiers.
  * new setting "assembly" to load assemblies from mmCIF as multi-state
    objects with all_states=1
  * new setting "cif_use_auth" controls whether mmCIF "auth" identifiers
    are used or not (on by default)
  * mmCIF "CA/P ATOMS ONLY" chains: set atom-level cartoon_trace_atoms
    and ribbon_trace_atoms
  * CIF discrete and irregular multi-model loading support
  * support "pdb_honor_model_number" setting for CIF
  * load multiple objects ("data_" blocks) from one CIF file (multiplex=-1)
  * don't store AtmToIdx, DiscreteAtmToIdx or DiscreteCSet to PSE
    (unless pse_export_version <= 1.76)
  * make python2.6 compatible
* Tue May  5 2015 dhall@wustl.edu
- update to 1.7.6.0
  * fix crash when loading malformed CIF file
  * cif export fix for natoms = 0
  * ignore SCALE matrices with negative determinant
  * fix memory leaks with iterate/alter
  * fix crash when saving PSE with deleted ramp
  * VASP file support for: CHGCAR, OUTCAR, POSCAR, XDATCAR
  * psf file support
  * fix several memory leaks
  * fix memory leak in get_global_components_bond_dict
  * new setting: pse_export_version to save to old session formats
  * change default: pdb_conect_nodup 0 -> 1
  * sphere_mode=-1 -> 9 if shaders available else 0
  * fix Tcl/Tk File menu unicode handling
  * scenes: Restore the old behavior that when recalling a scene, all objects
    which were not present when storing the scene are disabled.
  * fix auto-complete for filenames with spaces
  * fix an object menu panel group ordering problem
  * remove unused variables (Partly applies https://sourceforge.net/p/pymol/bugs/166/)
  * lots of: char* -> const char*
  * remove inline Parse functions, simplify ParseFloat3List
  * make functions static
  * mmCIF: support CHEM_COMP_BOND from mmCIF file
  * residue information for MOL2 export
  * find > polar contacts > between chains
  * keep initial scene when restoring legacy scenes
  * remove static PFNGL* function declarations
    https://sourceforge.net/p/pymol/bugs/165/
  * removed obsolete code and settings: use_display_lists, simplify_display_lists, excl_display_lists_shaders
  * rename _PYMOL_OPENGL_SHADERS -> _PYMOL_ARB_SHADERS
  * SingletonPyMOLGlobalsNULL.patch
  * https://sourceforge.net/p/pymol/bugs/162/
  - Free ShaderMgr after Scene
  - check (G != NULL) in MainOnExit
  * https://sourceforge.net/p/pymol/bugs/161/
    apply clang logical-op-parentheses suggestion
  * more `const char *` arguments refactoring
  * fixed roving density and roving detail demos (regression from last commit)
    http://sourceforge.net/p/pymol/bugs/156
  * fix "narrowing conversion" C++ errors
  * removed unused code and preprocessors:
    _PYMOL_GL_DRAWARRAYS
    _PYMOL_GL_CALLLISTS
    _PYMOL_CGO_DRAWARRAYS
    _PYMOL_CGO_DRAWBUFFERS
    OPENGL_ES_1
    OPENGL_ES_2
  * removed deprecated "register" specifier
  * mmCIF _atom_sites.fract_transf support (SCALEn equivalent)
  * Complete port of scenes to C++
  * warn user if setting a setting on the wrong level
  * cmd.extendaa: shortcut for cmd.extend with argument auto-completion
  * reduced memory footprint of AtomInfoType
  * expose "reps" to iterate/alter
  * expose "protons" to iterate/alter
  * adaptive cartoon quality and sampling, depending on number of atoms
  * fix ring center color with cartoon_ring_color=default
  * make SelectorGetTmp strictly molecular, fixes for example "dss" with group names
  * fix "copy" can cause crash
  * fix "custom" selection operator
  * consider spec_count in shaders
  * don't invalidate shaders for lighting settings
  * don't disable shaders for all Intel chips
  * don't touch sphere_mode when disabling shaders
  * map_new buffer == -1 -> gaussian_resolution
  * fix all_states picking
  * remove cylinder_shader_ff_workaround and cylinders_shader_filter_faces
  * remove unused gl_ambient setting
  * fix Tcl/Tk menu settings logging
  * fix: grid mode scales down label size incorrectly
  * fix: no animate argument for cmd.origin
  * fix side_chain_helper for hetatm polymer atoms
  * fix .mmd export
  * refactor many function to take "const" pointer arguments
* Thu Mar 12 2015 dhall@wustl.edu
- update to svn rev 4108
  * Fix error with multiple open "Save Molecule" dialogs
  * https://sourceforge.net/p/pymol/mailman/message/33286949/
  * fix windows build, PRIu64
  * cmd.as -> cmd.show_as in old test files
  * remove obsolete pymol2/make_cmd2.py
* Mon Jan  5 2015 dhall@wustl.edu
- update to svn rev 4107
  * elimination of more compiler warnings
  * silence numpy deprecation warnings (NPY_1_7_API_VERSION)
  * fix cif export with multiple objects
  * glutLeaveFullScreen: fix for freeglut < 2.6 and < 2.8
* Thu Dec  4 2014 dhall@wustl.edu
- update to pymol 1.7.4.0
  * use COMPONENTS_CIF environment variable to look for components.cif
  * update fetchHosts and hostPaths URLs
  * change order of mmCIF _atom_site columns on export
  * use _atom_site.label_asym_id as segi
  * cif: read first_model_num
  * fixed _foo?bar lookup could fail in mmCIF parsing
  * deprecated full_screen setting (use full_screen command)
  * fix collada_* settings in pymol.settings
  * fix apbs_tools for tcl/tk 8.6
  * fix fullscreen on OSX w/ GLUT
  * silence compiler warnings
* Thu Oct 30 2014 dhall@wustl.edu
- add libxml dependencies
* Mon Oct 20 2014 dhall@wustl.edu
- update to svn rev 4098
  * setup.py and plugin manager fixes
  - thanks to Justin Lecher for the bug reports
  * COLLADA (dae) export support
  - Implemented by Jared Sampson as his POSF project.
  * fast CIF loading, 1.7.3.1 (unstable/experimental)
  * fast PDBx/mmCIF and core CIF loading in C++
  * new connect_mode=4 does bonding with components.cif dictionary
    (mmCIF only, components.cif needs to be present in current
    directory)
  * gray out residues in the sequence viewer that are missing from the
    current state; Read missing residues from mmCIF files
    (_pdbx_unobs_or_zero_occ_residues records) so that they show up in
    the sequence viewer
  * add spider map reading support
  * load "map" as ccp4 instead of throwing "ambiguous" error
  * xyz write support
  * Improve right-button zoom: use origin instead of clipping slab
    center as depth indicator, fixes zoom speed when far clipping plane
    is very far away
  * don't use dynamic_width for nonbonded rep
* Wed Oct  1 2014 dhall@wustl.edu
- update to svnrev 4095
  * delete obsolete layer*/Makefile.*
  * ignore SCALEn if CRYST1 is 1x1x1 or invalid
  * new/refactored API functions for accessing coordinates and maps as numpy arrays
  * new API function: cmd.set_state_order
  * Session file (PSE) support for callback objects
  * fix/silence many compiler warnings
  * fix bg_rgb_top/bg_rgb_bottom side effects
  * revert "fix setting surface_circumscribe"
  * delete some obsolete files
* Mon Sep 15 2014 dhall@wustl.edu
- update to svnrev 4093
  * fix ObjectMoleculeCopy lex ref counting
  * added missing function pymol.menu.measurement_color
  * multi-letter chain support
  * c++ for all PyMOL c files
  - renaming files c -> cpp
  - c++ specific syntax (::)
* Mon Aug 25 2014 dhall@wustl.edu
- update to svnrev 4088
  * port pdb_conect_nodup to open-source PyMOL
  * reimplement volume carving
  - use a carve mask texture
  * fix boxed volume around selection (with or without carving)
  - this only worked for symmetry expanded volumes
  - still limited to maps with symmetry information (TODO)
  * removed ObjectVolumeGetIsUpdated, deprecate get_volume_is_updated
  * refactored ObjectVolumeStateGetField, ObjectVolumeGetField
  - don't keep a redundant vs->volume copy in memory
  * revert a 1.7.2 opaque_background change
  - real-time rendering background was always black with
    opaque_background=0
  - removes opaque_background support for "draw"
* Fri Aug  8 2014 dhall@wustl.edu
- update to svnrev 4086
  * chempy.cif: fix symmetry loading
  * Improve ObjectVolume rendering latency
  * Improve label edge pixel rounding
  * alter_state auto completion
  * improve "Label" wizard
  * re-implemented ObjectMoleculeSetDiscrete
  * fix ObjectMoleculeSetDiscrete for empty molecules (crashed PyMOL)
    regression by rev 4083
  * fix mutagenesis bump_scores error: after apply or clear, bump_scores must be cleared
    regression by rev 4081
  * improve "Label" wizard
  * re-implemented ObjectMoleculeSetDiscrete
  * fix label_digits crash
  * fixed get_angle3f to use doubles internally
  * avoid ZeroDivisionError in Volume Panel
  * support opaque_background with "draw"
  * fix spheroid command for use_shaders=0
  * report clash score in mutagenesis wizard
  * change defaults for settings "ribbon_as_cylinders" and
    "nonbonded_as_cylinders" to 0
  * new commands (ported from PSICO): join_states, alphatoall, loadall,
    centerofmass, extra_fit, api
  * pubchem and emd fetch support
  * support to run pml and py script with the "load" command
  * Fix text mode (text=1) with white background color
* Fri Jun 27 2014 dhall@wustl.edu
- update to svnrev 4080
  * chempy.cif: don't bond metalc and hydrog
  * chempy.cif: fix copy/paste typo in read_struct_conn_
  * better CIF support, etc.
  * refactor chempy.cif
  - support for multi-model
  - read secondary structure
  - rewritten tokenizer
  * atom sorting: make segi match case sensitive
  * fix/improve:
    A > compute > surface area > ...
    A > generate > selection > surface atoms
  * PDB parser: factor out SS handling for readability
  * open file dialog in CWD until the first file was selected, then
    remember that directory
  * with -J immediatly cd to $HOME (or $HOME/Documents on Windows).
    This allowes to put a "cd ..." in pymolrc
  * fix stereo shader invalidation
  * add missing header
* Wed May 14 2014 dhall@wustl.edu
- update to svn rev 4076
  * fix label depth issues with label_position
  * fix label reappeared when zoomed in too far
  * fix "scene auto, update" with wizard message
  * fix setting surface_circumscribe
  * volume improvments:
  - grid_mode support
  - adjust volume ramp alphas by number of layers
  - support TTT matrix
  - bind mouse wheel to volume panel to adjust all alphas at once
  * CCP4 map type 0 support
  * fixed polymer detection for intra-residue N->C and O3'->P bonds
  * raise exception when assigning arbitrary string to int setting
  * fix group visibility issue in movie making
* Thu Apr 24 2014 drhall@bu.edu
- update to svn rev 4074
  * never assign atom_type (noInvalidateMMStereoAndTextType)
  * fix ExecutivePurgeSpec memory leak
  * fix cartoon memory leak
  * fixed small solvent_radius crashes surface generation
* Thu Mar 13 2014 dhall@wustl.edu
- update to svn rev 4073
  * fix CGO ALPHA should not make colors get ignored
  * volume API and panel improvements
  * volume presets
  * new commands: volume_color, volume_ramp_new
  * improved volume panel/UI
  * custom volume ramps/presets
  * support for volumes from maps with transformation matrix (matrix_copy on map)
  * fix distorted labels with stereo walleye/crosseye
  * fix broken label scaling on Linux
  * update splash
  * bugfix: labels missing on some ATI cards
  * th_assert -> ok_assert
  * fix typo in menu: isolevel -1.5
  * set PYMOL_PATH=. if unknown and cannot be guessed
  * use PYMOL_DATA in ShaderMgr
  * remove some old code in pymol/__init__.py
  * http://sourceforge.net/p/pymol/bugs/147/
  * add method chempy.brick.Brick.from_numpy
  * mutagenesis wizard: use PYMOL_DATA
  * fix pymolrc lookup on Windows from users home directory broken
  * read space group from CCP4 maps
  * handle empty space group like P1 (for best support of map formats
    which do not have a space group)
  * map_auto_expand_sym: take symmetry from map if molecular object
    doesn't have symmetry information
  * gracefully reject writing MOL format with >999 atoms
  * fix: saving MOL2 format with empty atom name
  * fix: ray+png in batch mode ray traces twice
  * disable seq_view in mpng
  * change movie_quality default to 90 (was 60)
  * fix needs_alpha_reset
  * apbs_tools PDB writing: disable putting spaces before dashes
* Sat Jan  4 2014 dhall@wustl.edu
- update to svn rev 4058
  * fix ramp coloring when loaded from PSE
  * don't set use_shaders with PSE or reinitialize
  * delete duplicates when loading PSE w/ partial=1
  * fix incomplete CGO loading from session file
  * fix viewport logging syntax error
  * fixed typo in RepDihehral "ok &+" -> "ok &="
    http://sourceforge.net/p/pymol/bugs/146/
  * fix warnings about unused data argument
  * submenus can be callables which return a list
  * fix antialiasing internal edges, ray tracing
  * fix clicking volume panel dots at zero alpha
  * fix molecular weight w/ aromatic bonds & missing hydrogens
  * fixed sequence text/background when scrollbar isn't shown
  * remove deprecated mray command
* Fri Dec  6 2013 dhall@wustl.edu
- update to svn rev 4053
  * remove self assignments
    http://sourceforge.net/p/pymol/bugs/143/
  * cmd.load_callback: import fixed version to api
  * don't sort atoms in discrete objects
  * fix resizing issue for lines on ATI cards
  * fix reset stereo with reinitialize
  * fix draw stereo
  * fix label shader fog blending
* Mon Nov 11 2013 dhall@wustl.edu
- update to svn rev 4051
  * fix segfault in SceneImagePrepareImpl
  * fix dihedral rep for objects with >20 states
  * cmd.png: consider image_dots_per_inch with _unit2px
  * preset.py: delete temporary selections
  * fixed CGO demo crash in CGOSimplify
  * print OpenGL info not only to STDOUT, but to PyMOL text output
  * fix tcl/tk window placement on OS X 10.9
  * get_viewport: do not print int as float
  * fix: do not set wiz.cmd to None when saving PSE
  * fix cartoon picking bug
  * fix crash during selection
  * fix two_sided_lighting cartoon shader bug
  * fix isolevel command for isosurface with shaders
  * mol2 writing with multiple objects
  * fix removing non-polar hydrogens
  * fix crash during select bychain
  * fixed line_as_cylinder bug
  * fixed smooth half bonds with line as cylinders
  * get_bond command
* Mon Nov 11 2013 dhall@wustl.edu
- Add no-build-date.patch : eliminates build date in executable
* Mon Nov 11 2013 dhall@wustl.edu
- update to svn rev 4050
  * fix splash.png sRGB profile, https://sourceforge.net/p/pymol/bugs/136/
  * fix get_setting_updates
  * improve Filter Wizard, "Create Filtered Object"
  * consider "ignore_pdb_segi" setting when saving to PDB
  * delete obsolete files (sglite, ExtensionClass)
  * some C code refactoring
  * remove out-dated pymol.opengl module
  * enhance get_version command, quiet=-1 gives build information
  * remove max_triangles setting (was unused)
  * fcmp equals operator approximate match
  * fix Tcl/Tk save multiple to one file
* Mon Oct  7 2013 dhall@wustl.edu
- Drop setup.patch: upstream fixed bug
- update to svn rev 4045
  * fix setup.py sys.argv
* Sat Oct  5 2013 dhall@wustl.edu
- update to svn rev 4044
  * fix segfault in OrthoRenderCGO https://sourceforge.net/p/pymol/bugs/137/
  * importing.load_coords
  * improve util.chainbow
  * fix plugin manager PyMOLWiki URL install: strip whitespace
  * major re-work/organization of RepSphere.c and fixed sphere picking
  * fix color type settings return format for hex colors (0x prefix)
  * fix special keys in wizard input prompt
* Mon Sep  9 2013 dhall@wustl.edu
- update to svn rev 4042
  * add "x" "y" "z" selection operators
  * fix seq viewer background color
  * add "backbone" and "sidechain" selection keywords
  * fix: cealign inverts target structure
  * fix [bugs:#135] array overrun
  * apply one part of [patches:#6]
  * preserve "use_shaders" setting when loading session files
  * simplify pymolrc search routine
  * fix CtSh-M click on group members in object menu panel
  * set_key string support
* Fri Aug 23 2013 dhall@wustl.edu
- Add setup.patch: Makes pymol build using standard distutils commands
- update to svn rev 4039
  * fix h_add atom sorting
  * add "metals" keyword to selection language
  * improve amber rst/crd support
  * fix pair_fitting with one atom pair
  * setup.py: add --osx-frameworks agument
  * rpc server: use register_instance
  * fix numpy/ndarrayobject.h import
* Wed Jul 17 2013 dhall@wustl.edu
- update to svn rev 4035
  * fixed load_traj with stop/max arguments. Thanks to David Osguthorpe for the patch.
  * fix pymol.importing.read_mmodstr
  * proper numpy support (ObjectMap.c)
  * take out broken experimenting.expfit
  * fetch_path: graceful error handling when writing file fails
  * fixed flickering ortho problems on some machines
* Thu Jun 27 2013 dhall@wustl.edu
- update to svn rev 4033
  * fixed selection indicators
  * invalidation of selection indicators when selections change
  * wrong sized selection indicators are shown after zoom
* Tue Jun 18 2013 dhall@wustl.edu
- update to svn rev 4032
  * fixed loading in bg_rgb settings from old project pse files
  * add URL support for run command
  * some setup.py adjustments
  * fixed labels when use_shaders is 0 and show_frame_rate is on
  * update APBS Tools plugin
  * fix spectrumany when minimum/maximum are provided
* Wed Jun 12 2013 dhall@wustl.edu
- PyMOL v1.6.0.0 Release
  * freeing VBOs properly when deleting volumes
  * added quiet flag for SettingGenerateSideEffects() and SettingCheckUseShaders()
  * fix 15bit color picking
  * fix surface memory leak
  * fix CGO demo
  * internal.file_read: use urllib2 instead of urllib
  * fix ellipsoid transparency OpenGL rendering
* Tue Jun  4 2013 dhall@wustl.edu
- update to sven rev 4029
  * fix Scripts ending with ...pymol.py do not execute
    https://sourceforge.net/p/pymol/bugs/46/
  * several CGO fixes
  * several python fixes
* Fri Apr 26 2013 dhall@wustl.edu
- update to svn rev 4028, pymol 1.6beta1
  * refactored importing.fetch
  * spectrum enhancements (arbitrary expressions and colors)
  * pymol2.cmd2: implement proxy pattern
  * chempy model improvements
  * fix bg_color, which sometimes did not apply instantly
* Mon Apr 22 2013 dhall@wustl.edu
- update to svn rev 4027
  * support full path for "matrix" argument
    https://sourceforge.net/p/pymol/patches/4/
  * use PyMOL API in pymol.rpc module
    https://sourceforge.net/p/pymol/patches/3/
  * doc string for cmd.find_pairs
    https://sourceforge.net/p/pymol/patches/2/
  * rotate ANISOU vector when transforming objects
  * new command: split_chains
  * fix create/extract bug with movie
  * fixed cartoon VBO memory leak
  * always draw rounded caps with sticks shaders
  * several shader fixes and performance improvements
  * fixed screen z-offset for labels
* Mon Apr 22 2013 dimstar@opensuse.org
- Add freetype2-devel: the source #includes ft2build.h, so it's
  only correct to build require it.
* Sun Mar 24 2013 dhall@wustl.edu
- version bump: pymol 1.6
  * improved rendering performance using shaders, including
    dynamically updated shaders based on settings
    (see data/shaders directory)
  * implemented shaders for menus, labels, selection indicators,
    background, and other graphics that were not using shaders.
  * consolidated textures used for labels and selection indicators
    to one texture, which helps performance
  * added memory checking to help avoid crashing when memory is
    low or not available
  * cleaned up code base, took out extraneous preprocessor code and
    code that was not used.
  * refactor pmg_tk.Settings
  * Do not clear atom names with chempy.champ.assign.amber99
  * fix some plugin manager exception handling
  * fix create with name=None
  * Plugin override search path: Always include "startup"
    from installation directory in plugin search path
  * Movie > Program > Scene Loop > Nutate > by degrees
  * ObjectMeshRenderImpl refactoring: color isomesh and isodot with
    mesh_color and dot_color settings
  * merging alignment objects: eliminate orphaned atoms
  * fix cealign alignment object creation: rms_cur arguments swapped
  * improved the alignto command to take additional keyword arguments
    which get passed to the used method -> object=aln supported now
  * remove _PYMOL_MODULE constant
  * fix LITERAL mode command parsing: ignore leading whitespace
* Wed Mar 20 2013 dhall@wustl.edu
- update to svn rev 4023
  * setup.py: unify Linux and Mac platform-specific stuff
  * disable shaders for nouveau driver
  * setup.py: add support for incremental build
  * add missing file "qmplugin.h"
* Sat Feb 16 2013 dhall@wustl.edu
- update to svn rev 4020
  * enable VMD plugins by default
  * apply patch #120 "pymol" import in launcher ambiguous
    http://sourceforge.net/p/pymol/bugs/120/
  * always import _cmd from pymol or pymol.cmd instead of relative
  * add bz2 support for reading PDB and some other file formats
  * support width/height units with the png command
  * support decorator syntax for cmd.extend
  * setup.py refactoring, setup2.py no longer needed
  * Exit on error with "-y" flag
  * shortcut and auto-completion refactoring
  * fix setting angle_color or dihedral_color
  * ramp_new: exception handling on argument parsing
  * feedback fixes
  * speed up iterate and alter - https://sourceforge.net/p/pymol/patches/5/
  * command line (Tk GUI) history improvements
  * add angles to the Movie-Program-SceneLoop menu
  * Fixed fab hydro argument
  * Fixed #3539436: right justified resn in PDB
  * Fixed #3506103: alignment objects from "super" do not contain N atoms
  * Fixed #3496006: END before ENDMDL bug reintroduced
* Thu Aug 16 2012 dhall@wustl.edu
- update to svn rev 4005
  * Fixed longstanding annoyance: 'as rep, vis' now works
  * Added autocomplete for 'group' command.
  * Adding autocomplete for 'dss'.
  * Fixed bug where FASTA strings aren't returned for multiple objects.
* Sun Jun 10 2012 dhall@wustl.edu
- update to svn rev 4001
  * FIXED: fails to align chains of length < 2*window+1
  * FIXED: if chain length is a multiple of window, only (length-window) residues get aligned
  * FIXED: only evaluates every 2nd path of the best 20 (increments k twice in the loop)
  * FIXED: if no alignment is found, the return value is NULL which raises a SystemError instead of a graceful error message.
  * FIXED: finally, it's not possible to obtain the alignment as an object (like with align ..., object=aln)
  * FIXED: fixed auto complete names on for cealign
  * Fixing the exception handling of get_names_of_type
  * Fixing get_unused_names
  * Fixing locking on get_names_of_type
* Sat May  5 2012 dhall@wustl.edu
- Adding checks for Quadro cards
- Improved Plugin Manager; Thomas Holder's PyMOL OSFP project
* Fri Apr 13 2012 dhall@wustl.edu
- update to svn rev 3996
  * Fixed ID: 3512313 TER records before residues like MSE, patch submitted by Thomas Holder
  * Fixed ID:3513708, cmd.get_unused_name fix; thanks to Thomas Holder
  * Default all Intel cards to not use shaders
* Tue Mar  6 2012 dhall@wustl.edu
- update to svn rev 3993
  * fixed crash when reading in long lines from stdin
- update to 1.5.0.3
  * fixed error showing Cell on map with attached file
  * fixed reading in symmetry
  * fixed problem with symmetry copying/setting where map doesn't get updated
  * get_symmetry should return None if argument is not an ObjectMolecule or ObjectMap
  * fixed Volume extents only get shown when volume is rendered
  * fixed reading in legacy sessions with version # less than 1
* Sat Feb 18 2012 dhall@wustl.edu
- update to 1.5.0.2
  * stack trace when saving movie as MPEG (ID: 3488608)
  * error loading from pse that don't have Crystal/Symmetry info (ID: 3488609)
* Mon Feb 13 2012 dhall@wustl.edu
- update to 1.5.0.1 release
  * improved rendering Performance
  * improved rendering Quality
  * bg_gradient now ray traces
  * improved cartoon support for non-standard nucleotides
  * surface color smoothing
  * surface-based picking
  * frame buffer-based antialiasing for real-time rendering
  * optimized anaglyph colors and intensities for an improved 3D
  viewing experience
  * real-time and ray-traceable ambient occlusion
  * molecular weight calculuations; A > Compute > Molceular Weight
  * selection generation A > Generate > Selection
  * new mouse mode for repositioning lights
  * many bug fixes
* Fri Feb 10 2012 cfarrell@suse.com
- license update: Python-2.0
  Use the SPDX identifier (http://www.spdx.org/licenses)
* Wed Jan  4 2012 dhall@wustl.edu
- update to svn rev 3975
  * improved callback rendering
  * fixed object creation when merging two objects
  * fixed get_mass
  * fixed create to reorder IDs when combining objects
  * Cleaned up 'fitting.py'
  * alignto updated; can now take a method for alignment
  * cealign updated; made faster and cleaner
* Fri Oct 14 2011 dhall@wustl.edu
- update to svn rev 3971
  * Added the get_viewport function and updated the viewport function
  * Added support for some non-standard nucleic acids (PSU)
* Mon Oct  3 2011 dhall@wustl.edu
- update to svn rev 3969
  * PyMOL now respects the h_bond_from_proton setting
  * Doc fixes
  * Added Display > Roving Detail
  * Removed AttributeError on coloring volumes
  * Added polar contacts/hydrogen bonds to the measurement wizard
  * Fixed distance invalidation problem
* Fri Sep 16 2011 dhall@wustl.edu
- update to svn rev 3965
  * Fixed a conversion bug in util.cbc; thanks Hongbo.
  * Added A > Compute > Molecular Weight and cleaned up the compute menu in general
  * Fixed click-flash that happens when middle-clicking when showing the background
    gradient (thanks, Blaine)
  * Added A > Generate > Selection > polar, non_polar, acceptor/donator options
* Fri Aug  5 2011 dhall@wustl.edu
- update to svn rev 3962:
  * code cleanup
  * fix opengl from python
  * read and importing fixes
* Thu Jul  7 2011 dhall@wustl.edu
- Small state bugfix
- Feedback bugfix
- Updated TNT to 3.0b
* Sun Jul  3 2011 saschpe@gmx.de
- Spec file cleanup:
  * Added proper license header
  * Removed authors from description
* Fri Jun 17 2011 dhall@wustl.edu
- have just one package rather than pymol+python-pymol, maybe chempy
  will split out later
* Thu Jun 16 2011 dhall@wustl.edu
- update to svn version 3955
- fixed stick coloring
- fixed save mol file
- fixed shading/fog
- fixed volume shaders
- supress guess valences
* Thu Jun  2 2011 dhall@wustl.edu
- update to svn version 3951
- fix clipped group names
- much faster ribbons
* Tue May 10 2011 dhall@wustl.edu
- move pymol_path stuff into python module
* Tue May 10 2011 dhall@wustl.edu
- fix dependencies
- mark file as executable
* Tue May 10 2011 dhall@wustl.edu
  correct separation between pymol and python-pymol-
* Tue May 10 2011 dhall@wustl.edu
  Initial checkin of pymol 1.4.1-
